/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

/**
 * This file tests the L10nRegistry.jsm module.
 */


// Globals

var Cc = Components.classes;
var Ci = Components.interfaces;
var Cu = Components.utils;
var Cr = Components.results;

Cu.import("resource://gre/modules/L10nRegistry.jsm");

add_test(function test_object_exists() {

  do_check_true(this.hasOwnProperty('L10nRegistry'));
  run_next_test();
});


add_test(function test_default_resources_added() {
  const sourceInfo = L10nRegistry.requestSourceInfo();

  const sourceOrder = Array.from(sourceInfo.order);
  equal(sourceOrder[0], 'app');
  equal(sourceOrder[1], 'platform');
  equal(sourceOrder.length, 2);

  run_next_test();
});

add_task(function* test_getResources() {
  const result = yield L10nRegistry.getResources(['en-US'], [
    'browser/brand.ftl'
  ]);

  equal(result.bundles.length, 2);

  equal(Array.from(result.supportedLocales).length, 1);
  equal(result.bundles[0].locale, 'en-US');
  equal(result.bundles[0].resources['browser/brand.ftl'].locale, 'en-US');
  equal(result.bundles[0].resources['browser/brand.ftl'].source, 'app');
  equal(result.bundles[0].resources['browser/brand.ftl'].data, null);
});

add_task(function* test_fetchResource() {
  const result =
    yield L10nRegistry.fetchResource('app', 'browser/brand.ftl', 'en-US');

  equal(result, null);
});

add_test(function test_registerSource() {
  const langpackSource = new L10nRegistry.FileSource('langpack', '/path/foo');
  L10nRegistry.registerSource(langpackSource);

  const sourceInfo = L10nRegistry.requestSourceInfo();

  const sourceOrder = Array.from(sourceInfo.order);

  equal(sourceOrder[0], 'langpack');
  equal(sourceOrder.length, 3);

  run_next_test();
});


function run_test() {
  run_next_test();
}
